@@ -3,8 +3,8 @@ from pathlib import Path
 import zipfile
 
 from . import __version__, __repo__
-from .template import NewProjectTemplate
-from .filesystem import (load_proj_dict, TPR_INFO_FILENAME, CONVENTIONS,
+from .template import ProjectTemplate
+from .filesystem import (load_proj_dict, TPR_INFO_FILENAME, CONFIG,
         macro_loader, citation_loader, template_loader)
 
 def check_valid_project(proj_path):
@@ -25,19 +25,32 @@ def cli():
 @click.argument('output', type=click.Path())
 @click.option('--citation','-c',
         multiple=True)
-@click.option('--frozen/--no-frozen','-f',
+@click.option('--frozen/--no-frozen',
         default=False)
 def new(template, output, citation, frozen):
-    """Create a new project."""
+    """Create a new project. The project is created using the template with
+    name TEMPLATE and placed in the output folder OUTPUT. Citation files can be
+    specified by the citation flag, with multiple invocations for multiple
+    files. The frozen flag copies the project macro files directly rather than
+    creating symlinks.
+
+    The path OUTPUT either must not exist or be an empty folder. Missing
+    intermediate directories are automtically constructed."""
     output_path = Path(output)
 
     if output_path.exists():
-        raise click.ClickException(
-            f"project directory '{output_path}' already exists")
-    proj_gen = NewProjectTemplate(template, output_path.name.lstrip('.'), citation)
+        if not (output_path.is_dir() and len(list(output_path.iterdir())) == 0):
+            raise click.ClickException(
+                f"project path '{output_path}' already exists and is not an empty diretory.")
+    proj_gen = ProjectTemplate.load_from_template(
+            template,
+            output_path.name.lstrip('.'),
+            citation,
+            frozen=frozen)
     proj_gen.create_output_folder(output_path)
 
 
+# add copy .bbl option?
 @cli.command()
 @click.option('--directory',
         type=click.Path(),
@@ -47,7 +60,10 @@ def new(template, output, citation, frozen):
         show_default=True,
         default='zip')
 def export(directory, compression):
-    """Create a compressed export of an existing project."""
+    """Create a compressed export of an existing project. The compression
+    flag allows specification of the compression algorithm to be used.
+    The directory flag allows the program to specify the project directory,
+    and defaults to the current directory."""
     proj_path = Path(directory)
     check_valid_project(proj_path)
 
@@ -59,38 +75,41 @@ def export(directory, compression):
 
     export_zip = zipfile.ZipFile(proj_info['project']+'.' + compression,'w')
 
+    custom_files = [
+            f"{proj_info['project']}.tex",
+            f"{CONFIG['classinfo_file']}.tex",
+            f"{CONFIG['bibinfo_file']}.tex"]
+
     for p in proj_path.iterdir():
-        if p.suffix in CONVENTIONS['export_suffixes']:
+        if (p.suffix in CONFIG['export_suffixes'] and
+                p.name not in custom_files):
             export_zip.write(p,
                     compress_type=comp_dict[compression])
 
+    classinfo_text = (proj_path / f"{CONFIG['classinfo_file']}.tex").read_text()
+    bibinfo_text = (proj_path / f"{CONFIG['bibinfo_file']}.tex").read_text()
+    with open(proj_path / f"{proj_info['project']}.tex",'r') as project_tex_file:
+        proj_text = "".join(
+                classinfo_text if line.startswith(f"\\input{{{CONFIG['classinfo_file']}}}")
+                else bibinfo_text if line.startswith(f"\\input{{{CONFIG['bibinfo_file']}}}")
+                else line for line in project_tex_file.readlines())
+        export_zip.writestr(f"{proj_info['project']}.tex",proj_text)
     export_zip.close()
 
 @cli.command()
 @click.option('--directory',
         type=click.Path(),
         default='')
-def refresh(directory):
+@click.option('--force/--no-force',
+        default=False)
+def refresh(directory,force):
     """Regenerate project symbolic links."""
     proj_path = Path(directory)
     check_valid_project(proj_path)
 
-    proj_info = load_proj_dict(proj_path)
+    proj_info = ProjectTemplate.load_from_project(proj_path)
+    proj_info.write_tpr_files(proj_path,force=force)
 
-    # clear existing links
-    for p in proj_path.iterdir():
-        if p.stem.startswith(CONVENTIONS['macro_prefix']) or p.stem.startswith(CONVENTIONS['citation_prefix']):
-            p.unlink()
-
-    # add new macro links
-    if proj_info['macros'] is not None:
-        for pack in proj_info['macros']:
-            macro_loader.link_name(pack, proj_path)
-
-    # add new citation links
-    if proj_info['citations'] is not None:
-        for cit in proj_info['citations']:
-            citation_loader.link_name(cit, proj_path)
 
 # refactor this
 # have option positional argument for listing / descriptions?
@@ -125,3 +144,4 @@ MIT License.
         click.echo(f"Available {ld.user_str}s:")
         click.echo("\t"+"\t".join(ld.list_names()) + "\n")
 
+# add tpr clean function (remove not-in-use files, aux files, etc?)
