@@ -1,28 +1,37 @@
 from xdg import XDG_DATA_HOME, XDG_CONFIG_HOME
 from pathlib import Path
-from shutil import copy
+from shutil import copyfile
+from os import remove
 import yaml
 
 DATA_DIR = XDG_DATA_HOME / 'texproject'
 RESOURCES_DIR = DATA_DIR / 'resources'
-TPR_INFO_FILENAME = '.tpr_link_info'
+TPR_INFO_FILENAME = '.tpr_info'
 
-_CONVENTIONS_DIR = DATA_DIR / 'config' / '.tpr_config.yaml'
-_USER_CONFIG_DIR = XDG_CONFIG_HOME / 'texproject' / 'tpr_config.yaml'
+_CONFIG_DIR = DATA_DIR / 'config' / 'tpr_config.yaml'
+_USER_CONFIG_DIR = XDG_CONFIG_HOME / 'texproject' / 'config.yaml'
 
-_DEFAULT_TEMPLATE = DATA_DIR / 'config' / '.default_template.yaml'
+_DEFAULT_TEMPLATE = DATA_DIR / 'config' / 'default_template.yaml'
 _TEMPLATE_YAML_NAME = 'template.yaml'
 _TEMPLATE_DOC_NAME = 'document.tex'
 
+TEMPLATE_RESOURCE_DIR = Path('resources', 'other')
+_PROJECT_MACRO_TEMPLATE = TEMPLATE_RESOURCE_DIR / 'project_macro_file.tex'
+_CLASSINFO_TEMPLATE = TEMPLATE_RESOURCE_DIR / 'classinfo.tex'
+_BIBINFO_TEMPLATE = TEMPLATE_RESOURCE_DIR / 'bibinfo.tex'
+
 _MACRO_DIR = RESOURCES_DIR / 'packages' / 'macros'
-_FORMATTING_DIR = RESOURCES_DIR / 'packages' / 'formatting'
+_FORMAT_DIR = RESOURCES_DIR / 'packages' / 'format'
 _CITATION_DIR = RESOURCES_DIR / 'citations'
 _TEMPLATE_DIR = DATA_DIR / 'templates'
 
 def yaml_load_from_path(path_obj):
     return yaml.safe_load(path_obj.read_text())
 
-CONVENTIONS = yaml_load_from_path(_CONVENTIONS_DIR)
+def yaml_dump_proj_info(proj_path, template_dict):
+    (proj_path / TPR_INFO_FILENAME).write_text(yaml.dump(template_dict))
+
+CONFIG = yaml_load_from_path(_CONFIG_DIR)
 
 def load_user_dict():
     return yaml_load_from_path(_USER_CONFIG_DIR)
@@ -54,14 +63,23 @@ class FileLoader(BaseLoader):
         self.name_convention = name_convention
 
     def safe_name(self, name):
-        return f"{self.name_convention}{CONVENTIONS['prefix_separator']}{name}"
+        return f"{self.name_convention}{CONFIG['prefix_separator']}{name}"
 
-    def link_name(self, name, rel_path):
+    def link_name(self, name, rel_path,frozen=False,force=False):
         target_path = rel_path / (self.safe_name(name) + self.suffix)
-        if self.frozen:
-            copy(
-                    str(self.file_path(name).resolve(),
-                        str(target_path.resolve())))
+
+        if target_path.is_symlink():
+            target_path.unlink()
+        elif target_path.exists():
+            if force:
+                remove(target_path)
+            else:
+                return
+
+        if frozen:
+            copyfile(
+                    str(self.file_path(name).resolve()),
+                        str(target_path.resolve()))
         else:
             target_path.symlink_to(self.file_path(name))
 
@@ -81,19 +99,19 @@ macro_loader = FileLoader(
         _MACRO_DIR,
         '.sty',
         'macro file',
-        CONVENTIONS['macro_prefix'])
+        CONFIG['macro_prefix'])
 
-formatting_loader = FileLoader(
-        _FORMATTING_DIR,
+format_loader = FileLoader(
+        _FORMAT_DIR,
         '.sty',
-        'formatting file',
-        CONVENTIONS['formatting_prefix'])
+        'format file',
+        CONFIG['format_prefix'])
 
 citation_loader = FileLoader(
         _CITATION_DIR,
         '.bib',
         'citation file',
-        CONVENTIONS['citation_prefix'])
+        CONFIG['citation_prefix'])
 
 template_loader = TemplateLoader(
         _TEMPLATE_DIR,
